@@ -1,9 +1,9 @@
 use std::fs;
 use std::path::Path;
 
-use tau_engine::Rule;
+use tau_engine::{Error, Rule};
 
-pub fn load_rule(name: &str) -> Rule {
+pub fn load_rule(name: &str) -> Result<Rule, Error> {
     let rule = if name.ends_with(".yml") {
         name.to_owned()
     } else {
@@ -12,5 +12,5 @@ pub fn load_rule(name: &str) -> Rule {
     let root = env!("CARGO_MANIFEST_DIR");
     let path = Path::new(root).join("tests/rules").join(rule);
     let contents = fs::read_to_string(path).expect("failed to read rule");
-    Rule::load(&contents).expect("invalid rule")
+    Rule::load(&contents)
 }
